import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:puzzlegame/cubit/game_cubit.dart';
import 'package:puzzlegame/models/game/game.dart';
import 'package:puzzlegame/models/game/moving_tile.dart';
import 'package:puzzlegame/ui/widgets/game/game_tile.dart';

class GameTilesetwidget extends StatelessWidget {
  const GameTilesetwidget({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;

        final Color borderColor = currentGame.isFinished ? Colors.green : Colors.orange;
        final int tilesCount = currentGame.gameSettings.tilesetSizeValue;

        final List<MovingTile> tiles = currentGame.tiles;
        int tileIndex = 0;

        return Container(
          margin: const EdgeInsets.all(8),
          padding: const EdgeInsets.all(8),
          decoration: BoxDecoration(
            color: borderColor,
            borderRadius: BorderRadius.circular(8),
            border: Border.all(
              color: borderColor,
              width: 8,
            ),
          ),
          child: Table(
            defaultColumnWidth: const IntrinsicColumnWidth(),
            border: TableBorder.all(
              color: Colors.black,
              style: BorderStyle.solid,
              width: 2,
            ),
            children: [
              for (int row = 0; row < tilesCount; row++)
                TableRow(
                  children: [
                    for (int col = 0; col < tilesCount; col++)
                      Column(
                        children: [
                          GameTileWidget(
                            tile: tiles[tileIndex++],
                          )
                        ],
                      ),
                  ],
                ),
            ],
          ),
        );
      },
    );
  }
}
